==> flamerobin-0.7.2-src.tar.gz: flamerobin-0.7.2-src/src/gui/controls/DataGridCells.h <==
/*
Copyright (c) 2004, 2005, 2006 The FlameRobin Development Team

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be included
in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


  $Id: DataGridCells.h 1026 2006-04-13 19:32:05Z mghie $

*/

#ifndef FR_DATAGRIDCELLS_H
#define FR_DATAGRIDCELLS_H

#include <wx/wx.h>

#include "ibpp.h"
//----------------------------------------------------------------------
class wxMBConv;
//----------------------------------------------------------------------
// Abstract cell base class
class GridCell
{
public:
    virtual ~GridCell();
    virtual wxString getValue() = 0;

    static GridCell* createCell(IBPP::Statement& statement, int col,
        wxMBConv* converter);
};
//----------------------------------------------------------------------
#endif

==> flamerobin-0.7.5-src.tar.gz: flamerobin-0.7.5-src/src/gui/controls/DataGridCells.h <==
/*
Copyright (c) 2004, 2005, 2006 The FlameRobin Development Team

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be included
in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


  $Id: DataGridCells.h 1157 2006-06-04 12:04:07Z mghie $

*/

#ifndef FR_DATAGRIDCELLS_H
#define FR_DATAGRIDCELLS_H

#include <wx/wx.h>

#include "ibpp.h"
//----------------------------------------------------------------------
class wxMBConv;
//----------------------------------------------------------------------
// Abstract cell base class
class DataGridCell
{
public:
    virtual ~DataGridCell();
    virtual wxString getValue() = 0;

    static DataGridCell* createCell(IBPP::Statement& statement, int col,
        wxMBConv* converter);
};
//----------------------------------------------------------------------
#endif
